

set -ex



aarch64-conda_cos7-linux-gnu-addr2line --help
aarch64-conda_cos7-linux-gnu-ar --help
aarch64-conda_cos7-linux-gnu-as --help
aarch64-conda_cos7-linux-gnu-c++filt --help
aarch64-conda_cos7-linux-gnu-elfedit --help
aarch64-conda_cos7-linux-gnu-gprof --help
aarch64-conda_cos7-linux-gnu-ld --help
aarch64-conda_cos7-linux-gnu-ld.bfd --help
aarch64-conda_cos7-linux-gnu-ld.gold --help
aarch64-conda_cos7-linux-gnu-nm --help
aarch64-conda_cos7-linux-gnu-objcopy --help
aarch64-conda_cos7-linux-gnu-objdump --help
aarch64-conda_cos7-linux-gnu-ranlib --help
aarch64-conda_cos7-linux-gnu-readelf --help
aarch64-conda_cos7-linux-gnu-size --help
aarch64-conda_cos7-linux-gnu-strings --help
aarch64-conda_cos7-linux-gnu-strip --help
echo 10.2.0
exit 0
